==> apache-servicecomb-java-chassis-distribution-1.3.11-src.zip: apache-servicecomb-java-chassis-distribution-1.3.11-src/foundations/foundation-protobuf/src/main/java/org/apache/servicecomb/foundation/protobuf/RootSerializer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.foundation.protobuf;

import java.io.IOException;
import java.io.OutputStream;

import io.protostuff.ProtobufOutputEx;
import io.protostuff.SchemaEx;

public class RootSerializer {
  private SchemaEx<Object> schema;

  public RootSerializer(SchemaEx<Object> schema) {
    this.schema = schema;
  }

  public byte[] serialize(Object value) throws IOException {
    ProtobufOutputEx output = new ProtobufOutputEx();
    if (value != null) {
      schema.writeTo(output, value);
    }
    return output.toByteArray();
  }

  public void serialize(OutputStream outputStream, Object value) throws IOException {
    ProtobufOutputEx output = new ProtobufOutputEx();
    if (value != null) {
      schema.writeTo(output, value);
    }
    output.toOutputStream(outputStream);
  }
}

==> apache-servicecomb-java-chassis-distribution-2.8.16-src.zip: apache-servicecomb-java-chassis-distribution-2.8.16-src/foundations/foundation-protobuf/src/main/java/org/apache/servicecomb/foundation/protobuf/RootSerializer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.foundation.protobuf;

import java.io.IOException;
import java.io.OutputStream;

import io.protostuff.ProtobufOutputEx;
import io.protostuff.SchemaEx;

public class RootSerializer {
  private final SchemaEx<Object> schema;

  public RootSerializer(SchemaEx<Object> schema) {
    this.schema = schema;
  }

  public byte[] serialize(Object value) throws IOException {
    ProtobufOutputEx output = new ProtobufOutputEx();
    if (value != null) {
      schema.writeTo(output, value);
    }
    return output.toByteArray();
  }

  public void serialize(OutputStream outputStream, Object value) throws IOException {
    ProtobufOutputEx output = new ProtobufOutputEx();
    if (value != null) {
      schema.writeTo(output, value);
    }
    output.toOutputStream(outputStream);
  }
}
